# Contributing

Thank you for your interest in contributing to HeimdaLLM 🙏

Contributors must fill out a CLA (Contributor License Agreement) for their contributions
to be accepted.

- I plan on submitting contributions on behalf of myself: [Individual
  CLA](https://forms.gle/sZo4GKdvd8xr27d19)
- I plan on submitting contributions on behalf of my employer: [Corporate
  CLA](https://forms.gle/6Fa5ULsUbJgTkSXM7)

If you do not wish to sign a CLA, or your employer will not sign a CLA, the most
effective way to contribute is to open a Github Issue, explain your problem, and suggest
solutions, if known. Please do not spend time coding solution, as we cannot accept it
without a CLA. We will write the solution and integrate it to the codebase.
